/**
 * 
 */
package com.axemble.education.connectors.smtp;

import java.io.Serializable;
import java.util.Locale;
import java.util.Properties;

import javax.mail.Message;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

import com.axemble.vdoc.sdk.connectors.BaseConnection;
import com.axemble.vdp.localization.structures.LocalizationMap;
import com.axemble.vdp.ui.framework.foundation.Navigator;

public class SampleSMTPConnection extends BaseConnection
{
	private static final long serialVersionUID = 8575257148794814192L;

	public class InnerConnection implements Serializable
	{
		private static final long serialVersionUID = 8564201166004587558L;

		private Session session;
		private Transport transport;

		/**
		 * @param session
		 * @param transport
		 */
		public InnerConnection( Session session, Transport transport )
		{
			super();
			this.session = session;
			this.transport = transport;
		}
		public Session getSession()
		{
			return session;
		}
		public Transport getTransport()
		{
			return transport;
		}
	}

	/* (non-Javadoc)
	 * @see com.axemble.vdoc.sdk.connectors.BaseConnection#validate()
	 */
	@Override
	public boolean validate() throws Exception
	{
		Transport transport = null;
		try
		{
			// get a connection
			InnerConnection innerConnection = (InnerConnection)getConnection();
			if ( innerConnection == null )
				return false;

			String senderEmail = (String)getConnectionDefinition().getValue( SampleSMTPConnectionEditor.FIELD_MAIL_SENDER );
			String administratorEmail = (String)getConnectionDefinition().getValue( SampleSMTPConnectionEditor.FIELD_MAIL_ADMINISTRATOR );

			Session session = innerConnection.getSession();
			MimeMessage mimeMessage = new MimeMessage( session );
			mimeMessage.setSubject( "E-mail de test" );
			mimeMessage.setText( "Ceci est un test d'envoi d'e-mail" );

			mimeMessage.setFrom( new InternetAddress( senderEmail ) );
			InternetAddress[] internetAddresses = new InternetAddress[1];
			internetAddresses[0] = new InternetAddress( administratorEmail );
			mimeMessage.setRecipients( Message.RecipientType.TO, internetAddresses );

			transport = innerConnection.getTransport();
			transport.sendMessage( mimeMessage, mimeMessage.getAllRecipients() );

			return true;
		}
		catch( Exception e )
		{}
		finally
		{
			safeClose( transport );
		}
		return false;
	}
	@Override
	public String getErrorMessage( String language )
	{
		return getPortalModule().getStaticString( "LG_ERROR_MESSAGE", new Locale( language ) );
	}
	@Override
	public String getSuccessMessage( String language )
	{
		return getPortalModule().getStaticString( "LG_SUCCESS_MESSAGE", new Locale( language ) );
	}

	/* (non-Javadoc)
	 * @see com.axemble.vdoc.sdk.connectors.BaseConnection#getConnection()
	 */
	@Override
	public Object getConnection()
	{
		try
		{
			String serverName = (String)getConnectionDefinition().getValue( SampleSMTPConnectionEditor.FIELD_SMTP_SERVER );
			String portNumber = (String)getConnectionDefinition().getValue( SampleSMTPConnectionEditor.FIELD_SMTP_PORT );

			String smtpLogin = getPortalModule().getConfiguration().getStringProperty( "mail.smtp.login" );
			String smtpPassword = getPortalModule().getConfiguration().getStringProperty( "mail.smtp.password" );

			Properties prop = System.getProperties();
			prop.put( "mail.smtp.host", serverName );
			prop.put( "mail.smtp.port", portNumber );
			Session session = Session.getDefaultInstance( prop, null );

			Transport transport = session.getTransport( "smtp" );
			transport.connect( serverName, smtpLogin, smtpPassword );

			return new InnerConnection( session, transport );
		}
		catch( Exception e )
		{
			Navigator.getNavigator().getRootNavigator().showAlertBox( LocalizationMap.getString( "LG_TEST_SEND_MAIL_ERROR", Navigator.getNavigator().getRootNavigator().getUserFormat().getLocale() ) + e.toString() );
		}
		return null;
	}

	private void safeClose( Transport transport )
	{
		try
		{
			if ( transport != null )
				transport.close();
		}
		catch( Exception e )
		{
			Navigator.getNavigator().getRootNavigator().showAlertBox( LocalizationMap.getString( "LG_TEST_SEND_MAIL_ERROR", Navigator.getNavigator().getRootNavigator().getUserFormat().getLocale() ) + e.toString() );
		}
	}
}
